Removal change template
~~~~~~~~~~~~~~~~~~~~~~~

Enter description of methods/classes removed here....

Please rename file with PR number and your initials i.e. "99999-ABC.rst"
and ``git add`` the new file.
